From 8dc4d1d454a197890db4dab0b24cc6e0d65b5484 Mon Sep 17 00:00:00 2001
From: Pauli Virtanen <pauli.t.virtanen@jyu.fi>
Date: Mon, 29 Apr 2024 12:00:11 +0300
Subject: [PATCH] Documentation

---
 usadelndsoc/core.py | 31 +++++++++++++++++++------------
 1 file changed, 19 insertions(+), 12 deletions(-)

diff --git a/usadelndsoc/core.py b/usadelndsoc/core.py
index 43efe07..620c249 100644
--- a/usadelndsoc/core.py
+++ b/usadelndsoc/core.py
@@ -85,14 +85,14 @@ class Core:
     @property
     def x(self):
         """
         x-coordinates of the 2D cell grid
         """
         return np.linspace(-self.Lx / 2, self.Lx / 2, self._shape[0])
 
     @property
     def y(self):
         """
         y-coordinates of the 2D cell grid
         """
         return np.linspace(-self.Ly / 2, self.Ly / 2, self._shape[1])
 
@@ -122,31 +122,38 @@ class Core:
 
     U = _action_property(
         "U",
-        doc="""Wilson link matrices. Array, shape (nx, ny, 4(direction), 4, 4).
+        doc="""Wilson link matrices. Modifiable. Array, shape (nx, ny, 4(direction), 4, 4).
         The direction index is one of RIGHT(0)/UP(1)/LEFT(2)/DOWN(3).
         """,
     )
     Omega = _action_property(
-        "Omega", doc="Local energy matrix. Array, shape (nx, ny, 4, 4)."
+        "Omega", doc="Local energy matrix. Modifiable. Array, shape (nx, ny, 4, 4)."
     )
     mask = _action_property(
-        "mask", doc="""Material mask. Array of int, shape (nx, ny)"""
+        "mask", doc="""Material mask. Modifiable. Array of int, shape (nx, ny)"""
     )
     omega = _action_property(
         "omega",
         freeze=False,
-        doc="""Local energy matrix. Array of complex, shape (nx, nx, 4, 4)""",
+        doc="""Local energy matrix. Modifiable. Array of complex, shape (nx, nx, 4, 4)""",
     )
     hess_computed = _action_property("hess_computed")
     shape = property(
         fget=lambda self: self._shape, doc="""Array size of space, (nx, ny)"""
     )
-    Lx = _action_property("Lx", doc="""Total length of system in x-direction, float.""")
-    Ly = _action_property("Ly", doc="""Total length of system in y-direction, float.""")
+    Lx = _action_property(
+        "Lx", doc="""Total length of system in x-direction. Modifiable. (float)"""
+    )
+    Ly = _action_property(
+        "Ly", doc="""Total length of system in y-direction. Modifiable. (float)"""
+    )
     D = _action_property(
-        "D", doc="""Second gradient term prefactor (diffusion constant), float."""
+        "D",
+        doc="""Second gradient term prefactor (diffusion constant). Modifiable. (float)""",
+    )
+    eta = _action_property(
+        "eta", doc="""Hall term prefactor constant. Modifiable. (float)"""
     )
-    eta = _action_property("eta", doc="""Hall term prefactor constant, float.""")
 
     @property
     def hess_computed(self):
@@ -162,7 +169,7 @@ class Core:
 
     @property
     def Ux(self):
-        """Modifiable view to Wilson link matrix array, for RIGHT.
+        """Wilson link matrix array, for RIGHT. Modifiable view.
 
         The U for links to the LEFT is always the inverse of this.
         """
@@ -170,7 +177,7 @@ class Core:
 
     @property
     def Uy(self):
-        """Modifiable view to Wilson link matrix array, for UP.
+        """Wilson link matrix array, for UP.  Modifiable view.
 
         The U for links to DOWN is always the inverse of this.
         """
@@ -85,14 +85,14 @@ class Core:
     def x(self):
         """
-        x-coordinates of the 2D cell grid
+        x-coordinates of the 2D cell grid. Not modifiable.
         """
         return np.linspace(-self.Lx / 2, self.Lx / 2, self._shape[0])
@@ -85,14 +85,14 @@ class Core:
     def y(self):
         """
-        y-coordinates of the 2D cell grid
+        y-coordinates of the 2D cell grid. Not modifiable.
         """
         return np.linspace(-self.Ly / 2, self.Ly / 2, self._shape[1])
-- 
GitLab